@@ -39,7 +39,7 @@ module.exports = function (nylon_path) {
     /** load express module */
 
      console.log("work_dir::"+work_dir);
-    fscan.scan(work_dir + "/lib/modules", ".js", false, function (err, modelues) {
+    fscan.scan(nylon_path + "/lib/modules", ".js", false, function (err, modelues) {
       //  for (var i = 0; i < modelues.length; i++) {
          //   console.log("Load Module :: " + modelues[i]);
          //   require("./../modules/" + modelues[i])(app, nylon_path);
@@ -48,7 +48,7 @@ module.exports = function (nylon_path) {
         async.each(modelues, function (modelue, next) {
             logger.info("Load Module :: "  + modelue);
             try {
-               require("./../modules/" + modelue)(app, nylon_path);
+               require(nylon_path+"/lib/modules/" + modelue)(app, nylon_path);
                next();
             } catch (err) {
                
