@@ -1,6 +1,7 @@
 var passport=require('passport');
 var GoogleStrategy=require('passport-google-oauth20').Strategy;
-module.exports=function(config){    
+const config=require(process.cwd()+'/config/config');
+module.exports=function(){    
      passport.use(new GoogleStrategy(
         {
             clientID:config.oauth.google.clientId,
